// WStar Drawing program

//  PROPIX, Written by Pintr Gbor
// Szkesfehrvr, Krivnyi u. 15.
// H-8000, HUNGARY
// Tel: +36 30 9972445
// Fax: +36 22 304326
// Email: propix@mail.datatrans.hu
//        Pinter.Gabor@freemail.hu
// Web: www.propix.hu
//      www.datatrans.hu/propix

// Revisions:
//  V1.0  01/19/1997  First version written in C
//  V3.0  02/19/1998  Rewritten in Delphi 3
//  V5.0  08/25/2000  Recompiled with Delphi 5
//  V5.01 11/14/2000  More features, source reorganized
//  V5.02 11/30/2000  Transparent background added
//  V5.03 12/13/2000  PinyoDrawing is a component

unit ForegroundUnit;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs, StdCtrls, ExtCtrls, ComCtrls,
  DrawUnit;

type
  TForegroundForm = class(TForm)
    ForeColor: TColorDialog;
    ColorButton: TButton;
    StyleGroup: TGroupBox;
    SolidRB: TRadioButton;
    DashRB: TRadioButton;
    DotRB: TRadioButton;
    DashDotRB: TRadioButton;
    DashDotDotRB: TRadioButton;
    ModeGroup: TGroupBox;
    CopyRB: TRadioButton;
    XorRB: TRadioButton;
    OKButton: TButton;
    CancelButton: TButton;
    WidthLabel: TLabel;
    WidthEdit: TEdit;
    WidthUpDown: TUpDown;
    Sample: TPinyoDrawing;
    procedure ColorButtonClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure OKButtonClick(Sender: TObject);
    procedure ModeClick(Sender: TObject);
    procedure StyleClick(Sender: TObject);
    procedure WidthEditChange(Sender: TObject);
  end;

var
  ForegroundForm: TForegroundForm;

implementation

uses MainUnit;

{$R *.DFM}


//----------------------------------------------------------------------------------------------------------------------
// Initialize controls and interpret selection


// Initialize controls
procedure TForegroundForm.FormShow(Sender: TObject);
begin
  ForeColor.Color:= MainForm.PinyoDrawing.ForeColor;                            // Current color
  try
    WidthEdit.Text:=IntToStr(MainForm.PinyoDrawing.PenWidth);                   // Integer
  except
    WidthEdit.Text:='1';                                                        // Default
  end;
  case MainForm.PinyoDrawing.PenMode of                                         // Mode
    pmNotXor: XorRB.Checked:= True;
    else      CopyRB.Checked:= True;
  end;
  case MainForm.PinyoDrawing.PenStyle of                                        // Style
    psDash:        DashRB.Checked:= True;
    psDot:         DotRB.Checked:= True;
    psDashDot:     DashDotRB.Checked:= True;
    psDashDotDot:  DashDotDotRB.Checked:= True;
    else           SolidRB.Checked:= True;
  end;
  ForeColor.Color:= MainForm.PinyoDrawing.ForeColor;                            // Current color
  Sample.BackColor:= MainForm.PinyoDrawing.BackColor;                           // Current parameters to Sample
  Sample.ForeColor:= MainForm.PinyoDrawing.ForeColor;
  if MainForm.PinyoDrawing.BrushStyle=bsClear then
  begin
    Sample.BrushStyle:= bsSolid;                                                // Sample cannot be transparent
  end
  else
  begin
    Sample.BrushStyle:= MainForm.PinyoDrawing.BrushStyle;
  end;
  Sample.PenMode:= MainForm.PinyoDrawing.PenMode;
  Sample.PenStyle:= MainForm.PinyoDrawing.PenStyle;
  Sample.PenWidth:= MainForm.PinyoDrawing.PenWidth;
  Sample.Picture:= MainForm.PinyoDrawing.Picture;
  case MainForm.PinyoDrawing.Picture of                                         // Smaller and faster
    pcNephroid:
      begin
        Sample.Points:= 20;
      end;
    pcPascal:
      begin
        Sample.Points:= 30;
      end;
    else // pcStar:
      begin
        Sample.Points:= 9;
      end;
  end;
end;


// OK button click
procedure TForegroundForm.OKButtonClick(Sender: TObject);
var
  i : Integer;
begin
  MainForm.PinyoDrawing.ForeColor:= ForeColor.Color;                            // Color
  try
    i:=StrToInt(WidthEdit.Text);                                                // Width
    if (1<=i) and (i<=9) then MainForm.PinyoDrawing.PenWidth:=i;                // Set if acceptable
  except
  end;
  if CopyRB.Checked then MainForm.PinyoDrawing.PenMode:= pmCopy else            // Mode
  if XorRB.Checked  then MainForm.PinyoDrawing.PenMode:= pmNotXor;
  if SolidRB.Checked then MainForm.PinyoDrawing.PenStyle:= psSolid else         // Style
  if DashRB.Checked then MainForm.PinyoDrawing.PenStyle:= psDash else
  if DotRB.Checked then MainForm.PinyoDrawing.PenStyle:= psDot else
  if DashDotRB.Checked then MainForm.PinyoDrawing.PenStyle:= psDashDot else
  if DashDotDotRB.Checked then MainForm.PinyoDrawing.PenStyle:= psDashDotDot;
end;


//----------------------------------------------------------------------------------------------------------------------
// Controls


// Select color and repaint sample box
procedure TForegroundForm.ColorButtonClick(Sender: TObject);
begin
  if ForeColor.Execute then
  begin
    Sample.ForeColor:= ForeColor.Color;
  end;
end;


// Mode changed -> repaint sample box
procedure TForegroundForm.ModeClick(Sender: TObject);
begin
  if CopyRB.Checked then Sample.PenMode:= pmCopy else                           // Mode
  if XorRB.Checked  then Sample.PenMode:= pmNotXor;
end;


// Style changed -> check width and repaint sample box
procedure TForegroundForm.StyleClick(Sender: TObject);
begin
  if not SolidRB.Checked then
  begin
    WidthEdit.Text:= '1';                                                       // if Style<>Solid then width:=1
    Sample.PenWidth:= 1;
  end;
  if SolidRB.Checked then Sample.PenStyle:= psSolid else                        // Style
  if DashRB.Checked then Sample.PenStyle:= psDash else
  if DotRB.Checked then Sample.PenStyle:= psDot else
  if DashDotRB.Checked then Sample.PenStyle:= psDashDot else
  if DashDotDotRB.Checked then Sample.PenStyle:= psDashDotDot;
end;


// Width changed -> check style and repaint sample box
procedure TForegroundForm.WidthEditChange(Sender: TObject);
var
  i: Integer;
begin
  if (WidthEdit.Text<>'1') and not SolidRB.Checked then
  begin
    SolidRB.Checked:= True;                                                     // if Width>1 then Style:=Solid;
    Sample.PenStyle:= psSolid;
  end;
  try
    i:=StrToInt(WidthEdit.Text);                                                // Width
    if (1<=i) and (i<=9) then Sample.PenWidth:=i;                               // Set if acceptable
  except
  end;
end;

end.
